![PMS_logo_long](https://github.com/Airscker/Purple-Micro-Star/blob/Web/imgs/PMS.png?raw=true)

# MultiBody Celestial Motion Simulation

## Introduction

This is a package built for simulating Multibody Celestial motion and Gravitational Wave of Pulsars or Binary Celestial Bodies.

To install this package just using `pip`:
```
pip install PurpleMicroStar
```
And the document is available here at [Home Page of Purple Micro Star](https://airscker.github.io/Purple-Micro-Star/)


## Key Information
- Author: Airscker/Yufeng Wang
- License: GPL-3.0 License

## Key Folders
- CBIG_DATA: Compact Binary Inspiral Celestial Bodies' Gravitational Wave Data Images Generated by Project
- Curve_data: MultiBody Motion Curve Data generated by Project
- exampledata: MultiBoby Basic Properties. Saved as .csv file
- PurpleMicroStar: Containing All Open Source Code files